﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.SurrogateProblem {
  [StorableClass]
  [Item("DataPointDistance", "A distance wrapper for DataPoints")]
  internal class DataPointDistance<T> : DistanceBase<IDataPoint<T>> where T : class {

    #region properties
    [Storable]
    private IDistance<T> dist;
    #endregion

    #region HLConstructors
    [StorableConstructor]
    protected DataPointDistance(bool deserializing) : base(deserializing) { }
    public override IDeepCloneable Clone(Cloner cloner) { return new DataPointDistance<T>(this, cloner); }
    protected DataPointDistance(DataPointDistance<T> original, Cloner cloner) : base(original, cloner) { dist = cloner.Clone(original.dist); }
    public DataPointDistance(IDistance<T> distance) {
      dist = distance;
    }
    #endregion

    public override double Get(IDataPoint<T> a, IDataPoint<T> b) { return dist.Get(a.X(), b.X()); }
    public override double Get(IDataPoint<T> a, IDataPoint<T> b, double threshold) { return dist.Get(a.X(), b.X(), threshold); }

  }
}

